Struct google_vault1::api::HeldAccount[][src]

pub struct HeldAccount {
    pub account_id: Option<String>,
    pub email: Option<String>,
    pub first_name: Option<String>,
    pub hold_time: Option<String>,
    pub last_name: Option<String>,
}

An account being held in a particular hold. This structure is immutable. This can be either a single user or a google group, depending on the corpus.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

account_id: Option<String>

The account’s ID as provided by the Admin SDK.

email: Option<String>

The primary email address of the account. If used as an input, this takes precedence over account ID.

first_name: Option<String>

Output only. The first name of the account holder.

hold_time: Option<String>

Output only. When the account was put on hold.

last_name: Option<String>

Output only. The last name of the account holder.