Struct google_vault1::api::Matter[][src]

pub struct Matter {
    pub description: Option<String>,
    pub matter_id: Option<String>,
    pub matter_permissions: Option<Vec<MatterPermission>>,
    pub name: Option<String>,
    pub state: Option<String>,
}

Represents a matter.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

description: Option<String>

The description of the matter.

matter_id: Option<String>

The matter ID which is generated by the server. Should be blank when creating a new matter.

matter_permissions: Option<Vec<MatterPermission>>

List of users and access to the matter. Currently there is no programmer defined limit on the number of permissions a matter can have.

name: Option<String>

The name of the matter.

state: Option<String>

The state of the matter.