Struct google_vault1::api::RemoveMatterPermissionsRequest[][src]

pub struct RemoveMatterPermissionsRequest {
    pub account_id: Option<String>,
}

Remove an account as a matter collaborator.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

account_id: Option<String>

The account ID.