[][src]Struct google_vault1::Query

pub struct Query {
    pub terms: Option<String>,
    pub search_method: Option<String>,
    pub start_time: Option<String>,
    pub drive_options: Option<DriveOptions>,
    pub shared_drive_info: Option<SharedDriveInfo>,
    pub team_drive_info: Option<TeamDriveInfo>,
    pub mail_options: Option<MailOptions>,
    pub hangouts_chat_info: Option<HangoutsChatInfo>,
    pub data_scope: Option<String>,
    pub account_info: Option<AccountInfo>,
    pub org_unit_info: Option<OrgUnitInfo>,
    pub time_zone: Option<String>,
    pub corpus: Option<String>,
    pub end_time: Option<String>,
    pub method: Option<String>,
    pub hangouts_chat_options: Option<HangoutsChatOptions>,
}

A query definition relevant for search & export.

This type is not used in any activity, and only used as part of another schema.

Fields

terms: Option<String>

The corpus-specific search operators used to generate search results.

search_method: Option<String>

The search method to use.

start_time: Option<String>

The start time range for the search query. These timestamps are in GMT and rounded down to the start of the given date.

drive_options: Option<DriveOptions>

For Drive search, specify more options in this field.

shared_drive_info: Option<SharedDriveInfo>

When 'SHARED_DRIVE' is chosen as search method, shared_drive_info needs to be specified.

team_drive_info: Option<TeamDriveInfo>

When 'TEAM_DRIVE' is chosen as search method, team_drive_info needs to be specified.

mail_options: Option<MailOptions>

For mail search, specify more options in this field.

hangouts_chat_info: Option<HangoutsChatInfo>

When 'ROOM' is chosen as search method, hangout_chats_info needs to be specified. (read-only)

data_scope: Option<String>

The data source to search from.

account_info: Option<AccountInfo>

When 'ACCOUNT' is chosen as search method, account_info needs to be specified.

org_unit_info: Option<OrgUnitInfo>

When 'ORG_UNIT' is chosen as as search method, org_unit_info needs to be specified.

time_zone: Option<String>

The time zone name. It should be an IANA TZ name, such as "America/Los_Angeles". For more information, see Time Zone.

corpus: Option<String>

The corpus to search.

end_time: Option<String>

The end time range for the search query. These timestamps are in GMT and rounded down to the start of the given date.

method: Option<String>

The search method to use. This field is similar to the search_method field but is introduced to support shared drives. It supports all search method types. In case the search_method is TEAM_DRIVE the response of this field will be SHARED_DRIVE only.

hangouts_chat_options: Option<HangoutsChatOptions>

For hangouts chat search, specify more options in this field. (read-only)