Struct google_vault1::api::AddHeldAccountsRequest [−][src]
Add a list of accounts to a hold.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- holds add held accounts matters (request)
Fields
account_ids: Option<Vec<String>>Account IDs to identify which accounts to add. Only account_ids or only emails should be specified, but not both.
emails: Option<Vec<String>>Emails to identify which accounts to add. Only emails or only account_ids should be specified, but not both.