Struct google_vault1::api::AddMatterPermissionsRequest [−][src]
Add an account with the permission specified. The role cannot be owner. If an account already has a role in the matter, it will be overwritten.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- add permissions matters (request)
Fields
cc_me: Option<bool>Only relevant if send_emails is true. True to CC requestor in the email message. False to not CC requestor.
matter_permission: Option<MatterPermission>The MatterPermission to add.
send_emails: Option<bool>True to send notification email to the added account. False to not send notification email.