Struct google_vault1::api::Matter [−][src]
Represents a matter.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- exports create matters (none)
- exports delete matters (none)
- exports get matters (none)
- exports list matters (none)
- holds accounts create matters (none)
- holds accounts delete matters (none)
- holds accounts list matters (none)
- holds add held accounts matters (none)
- holds create matters (none)
- holds delete matters (none)
- holds get matters (none)
- holds list matters (none)
- holds remove held accounts matters (none)
- holds update matters (none)
- saved queries create matters (none)
- saved queries delete matters (none)
- saved queries get matters (none)
- saved queries list matters (none)
- add permissions matters (none)
- close matters (none)
- count matters (none)
- create matters (request|response)
- delete matters (response)
- get matters (response)
- list matters (none)
- remove permissions matters (none)
- reopen matters (none)
- undelete matters (response)
- update matters (request|response)
Fields
description: Option<String>The description of the matter.
matter_id: Option<String>The matter ID which is generated by the server. Should be blank when creating a new matter.
matter_permissions: Option<Vec<MatterPermission>>List of users and access to the matter. Currently there is no programmer defined limit on the number of permissions a matter can have.
name: Option<String>The name of the matter.
state: Option<String>The state of the matter.