Struct google_vault1::api::RemoveHeldAccountsRequest [−][src]
Remove a list of accounts from a hold.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- holds remove held accounts matters (request)
Fields
account_ids: Option<Vec<String>>Account IDs to identify HeldAccounts to remove.